<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>AppChooserDialog</name>
    <message>
        <location filename="../../app-chooser-dialog.ui" line="14"/>
        <source>Choose an Application</source>
        <translation>Sélectionnez une application</translation>
    </message>
    <message>
        <location filename="../../app-chooser-dialog.ui" line="36"/>
        <source>Installed Applications</source>
        <translation>Applications installées</translation>
    </message>
    <message>
        <location filename="../../app-chooser-dialog.ui" line="46"/>
        <source>Custom Command</source>
        <translation>Commandes personnalisées</translation>
    </message>
    <message>
        <location filename="../../app-chooser-dialog.ui" line="52"/>
        <source>Command line to execute:</source>
        <translation>Ligne de commande a exécuter :</translation>
    </message>
    <message>
        <location filename="../../app-chooser-dialog.ui" line="62"/>
        <source>Application name:</source>
        <translation>Nom de l’application :</translation>
    </message>
    <message>
        <location filename="../../app-chooser-dialog.ui" line="72"/>
        <source>&lt;b&gt;These special codes can be used in the command line:&lt;/b&gt;
&lt;ul&gt;
&lt;li&gt;&lt;b&gt;%f&lt;/b&gt;: Represents a single file name&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%F&lt;/b&gt;: Represents multiple file names&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%u&lt;/b&gt;: Represents a single URI of the file&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%U&lt;/b&gt;: Represents multiple URIs&lt;/li&gt;
&lt;/ul&gt;</source>
        <translation>&lt;b&gt;Ces codes spéciaux peuvent être utilisées dans la ligne de commande :&lt;/b&gt;
&lt;ul&gt;
&lt;li&gt;&lt;b&gt;%f&lt;/b&gt;: Represente un seul nom de fichier&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%F&lt;/b&gt;: Represente plusieurs nom de fichiers&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%u&lt;/b&gt;: Represente l’URI d&apos;un seul fichier&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%U&lt;/b&gt;: Represente plusieurs URIs&lt;/li&gt;
&lt;/ul&gt;</translation>
    </message>
    <message>
        <location filename="../../app-chooser-dialog.ui" line="91"/>
        <source>Keep terminal window open after command execution</source>
        <translation>Garder la fenêtre de terminal ouverte après exécution de la commande</translation>
    </message>
    <message>
        <location filename="../../app-chooser-dialog.ui" line="98"/>
        <source>Execute in terminal emulator</source>
        <translation>Exécuter dans un émulateur de terminal</translation>
    </message>
    <message>
        <location filename="../../app-chooser-dialog.ui" line="109"/>
        <source>Set selected application as default action of this file type</source>
        <translation>Définir l’application sélectionnée par défaut pour les fichiers de ce type</translation>
    </message>
</context>
<context>
    <name>EditBookmarksDialog</name>
    <message>
        <location filename="../../edit-bookmarks.ui" line="14"/>
        <source>Edit Bookmarks</source>
        <translation>Modifier les signets</translation>
    </message>
    <message>
        <location filename="../../edit-bookmarks.ui" line="42"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../../edit-bookmarks.ui" line="47"/>
        <source>Location</source>
        <translation>Emplacement</translation>
    </message>
    <message>
        <location filename="../../edit-bookmarks.ui" line="67"/>
        <source>&amp;Add Item</source>
        <translation>&amp;Ajouter un élément</translation>
    </message>
    <message>
        <location filename="../../edit-bookmarks.ui" line="77"/>
        <source>&amp;Remove Item</source>
        <translation>&amp;Supprimer un élément</translation>
    </message>
    <message>
        <location filename="../../edit-bookmarks.ui" line="102"/>
        <source>Use drag and drop to reorder the items</source>
        <translation>Utiliser le glisser-déposer pour trier à nouveau les éléments</translation>
    </message>
</context>
<context>
    <name>ExecFileDialog</name>
    <message>
        <location filename="../../exec-file.ui" line="14"/>
        <source>Execute file</source>
        <translation>Exécuter le fichier</translation>
    </message>
    <message>
        <location filename="../../exec-file.ui" line="39"/>
        <source>&amp;Open</source>
        <translation>&amp;Ouvrir</translation>
    </message>
    <message>
        <location filename="../../exec-file.ui" line="52"/>
        <source>E&amp;xecute</source>
        <translation>E&amp;xécuter</translation>
    </message>
    <message>
        <location filename="../../exec-file.ui" line="62"/>
        <source>Execute in &amp;Terminal</source>
        <translation>Exécuter dans un &amp;terminal</translation>
    </message>
    <message>
        <location filename="../../exec-file.ui" line="85"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>FileOperationDialog</name>
    <message>
        <location filename="../../file-operation-dialog.ui" line="32"/>
        <source>Destination:</source>
        <translation>Destination :</translation>
    </message>
    <message>
        <location filename="../../file-operation-dialog.ui" line="55"/>
        <source>Processing:</source>
        <translation>Traitement :</translation>
    </message>
    <message>
        <location filename="../../file-operation-dialog.ui" line="68"/>
        <source>Preparing...</source>
        <translation>Préparation…</translation>
    </message>
    <message>
        <location filename="../../file-operation-dialog.ui" line="75"/>
        <source>Progress</source>
        <translation>Progression</translation>
    </message>
    <message>
        <location filename="../../file-operation-dialog.ui" line="95"/>
        <source>Time remaining:</source>
        <translation>Temps restant :</translation>
    </message>
</context>
<context>
    <name>FilePropsDialog</name>
    <message>
        <location filename="../../file-props.ui" line="14"/>
        <source>File Properties</source>
        <translation>Propriétés du fichier</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="41"/>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="80"/>
        <source>Location:</source>
        <translation>Emplacement :</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="106"/>
        <source>File type:</source>
        <translation>Type de fichier :</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="129"/>
        <source>MIME type:</source>
        <translation>Type Mime :</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="152"/>
        <source>File size:</source>
        <translation>Taille du fichier :</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="175"/>
        <source>On-disk size:</source>
        <translation>Taille sur le disque :</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="198"/>
        <source>Last modified:</source>
        <translation>Date de dernière modification :</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="221"/>
        <source>Link target:</source>
        <translation>Cible du lien :</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="247"/>
        <source>Open With:</source>
        <translation>Ouvrir avec :</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="267"/>
        <source>Last accessed:</source>
        <translation>Date de dernier accès :</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="285"/>
        <source>Permissions</source>
        <translation>Droits d&apos;accès</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="300"/>
        <source>Ownership</source>
        <translation>Propriété</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="324"/>
        <location filename="../../file-props.ui" line="389"/>
        <location filename="../../file-props.ui" line="503"/>
        <source>Group:</source>
        <translation>Groupe :</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="337"/>
        <location filename="../../file-props.ui" line="372"/>
        <location filename="../../file-props.ui" line="451"/>
        <source>Owner:</source>
        <translation>Propriétaire :</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="353"/>
        <source>Access Control</source>
        <translation>Contrôle d’accès</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="406"/>
        <location filename="../../file-props.ui" line="555"/>
        <source>Other:</source>
        <translation>Autre :</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="423"/>
        <source>Make the file executable</source>
        <translation>Rendre le fichier exécutable</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="464"/>
        <location filename="../../file-props.ui" line="516"/>
        <location filename="../../file-props.ui" line="568"/>
        <source>Read</source>
        <translation>Lecture</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="477"/>
        <location filename="../../file-props.ui" line="529"/>
        <location filename="../../file-props.ui" line="581"/>
        <source>Write</source>
        <translation>Écriture</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="490"/>
        <location filename="../../file-props.ui" line="542"/>
        <location filename="../../file-props.ui" line="594"/>
        <source>Execute</source>
        <translation>Exécution</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="603"/>
        <source>Sticky</source>
        <translation>Permanent</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="610"/>
        <source>SetUID</source>
        <translation>SetUID</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="617"/>
        <source>SetGID</source>
        <translation>SetGID</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="653"/>
        <source>Advanced Mode</source>
        <translation>Mode avancé</translation>
    </message>
</context>
<context>
    <name>Fm::AppChooserComboBox</name>
    <message>
        <location filename="../../appchoosercombobox.cpp" line="67"/>
        <source>Customize</source>
        <translation>Personnaliser</translation>
    </message>
</context>
<context>
    <name>Fm::AppChooserDialog</name>
    <message>
        <location filename="../../appchooserdialog.cpp" line="262"/>
        <source>Select an application to open &quot;%1&quot; files</source>
        <translation>Sélectionnez une application pour ouvrir les fichiers de type &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>Fm::CreateNewMenu</name>
    <message>
        <location filename="../../createnewmenu.cpp" line="30"/>
        <source>Folder</source>
        <translation>Dossier</translation>
    </message>
    <message>
        <location filename="../../createnewmenu.cpp" line="34"/>
        <source>Blank File</source>
        <translation>Fichier vide</translation>
    </message>
</context>
<context>
    <name>Fm::DirListJob</name>
    <message>
        <location filename="../../core/dirlistjob.cpp" line="45"/>
        <source>The specified directory &apos;%1&apos; is not valid</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Fm::DirTreeModel</name>
    <message>
        <location filename="../../dirtreemodelitem.cpp" line="85"/>
        <source>Loading...</source>
        <translation>Chargement…</translation>
    </message>
    <message>
        <location filename="../../dirtreemodelitem.cpp" line="268"/>
        <location filename="../../dirtreemodelitem.cpp" line="312"/>
        <location filename="../../dirtreemodelitem.cpp" line="410"/>
        <source>&lt;No sub folders&gt;</source>
        <translation>&lt;Aucun sous-dossiers&gt;</translation>
    </message>
</context>
<context>
    <name>Fm::DirTreeView</name>
    <message>
        <location filename="../../dirtreeview.cpp" line="211"/>
        <source>Open in New T&amp;ab</source>
        <translation>Ouvrir dans un nouvel &amp;onglet</translation>
    </message>
    <message>
        <location filename="../../dirtreeview.cpp" line="215"/>
        <source>Open in New Win&amp;dow</source>
        <translation>Ouvrir dans une nouvelle &amp;fenêtre</translation>
    </message>
    <message>
        <location filename="../../dirtreeview.cpp" line="220"/>
        <source>Open in Termina&amp;l</source>
        <translation>Ouvrir dans un &amp;terminal</translation>
    </message>
</context>
<context>
    <name>Fm::DndActionMenu</name>
    <message>
        <location filename="../../dndactionmenu.cpp" line="32"/>
        <source>Copy here</source>
        <translation>Copier ici</translation>
    </message>
    <message>
        <location filename="../../dndactionmenu.cpp" line="35"/>
        <source>Move here</source>
        <translation>Déplacer ici</translation>
    </message>
    <message>
        <location filename="../../dndactionmenu.cpp" line="38"/>
        <source>Create symlink here</source>
        <translation>Créer un lien symbolique ici</translation>
    </message>
    <message>
        <location filename="../../dndactionmenu.cpp" line="41"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>Fm::EditBookmarksDialog</name>
    <message>
        <location filename="../../editbookmarksdialog.cpp" line="98"/>
        <source>New bookmark</source>
        <translation>Nouveau signet</translation>
    </message>
</context>
<context>
    <name>Fm::ExecFileDialog</name>
    <message>
        <location filename="../../execfiledialog.cpp" line="40"/>
        <source>This text file &apos;%1&apos; seems to be an executable script.
What do you want to do with it?</source>
        <translation>Le fichier texte &apos;%1&apos; semble être un script exécutable.
Qu voulez-voulez vous en faire ?</translation>
    </message>
    <message>
        <location filename="../../execfiledialog.cpp" line="45"/>
        <source>This file &apos;%1&apos; is executable. Do you want to execute it?</source>
        <translation>Le fichier &apos;%1&apos; est exécutable. Souhaitez-vous le lancer ?</translation>
    </message>
</context>
<context>
    <name>Fm::FileMenu</name>
    <message>
        <location filename="../../filemenu.cpp" line="82"/>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <source>OpenWith</source>
        <translation type="vanished">OpenWith</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="145"/>
        <source>Cut</source>
        <translation>Couper</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="149"/>
        <source>Copy</source>
        <translation>Copier</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="153"/>
        <source>Paste</source>
        <translation>Coller</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="157"/>
        <location filename="../../filemenu.cpp" line="348"/>
        <source>&amp;Move to Trash</source>
        <translation>&amp;Mettre à la corbeille</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="297"/>
        <source>Output</source>
        <translation>Sortie</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="348"/>
        <source>&amp;Delete</source>
        <translation>&amp;Supprimer</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="161"/>
        <source>Rename</source>
        <translation>Renommer</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="86"/>
        <source>Open With...</source>
        <translation>Ouvrir avec…</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="114"/>
        <source>Other Applications</source>
        <translation>Autres applications</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="120"/>
        <source>Create &amp;New</source>
        <translation>Créer un &amp;nouveau</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="139"/>
        <source>&amp;Restore</source>
        <translation>&amp;Restaurer</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="188"/>
        <source>Extract to...</source>
        <translation>Extraire vers…</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="193"/>
        <source>Extract Here</source>
        <translation>Extraire ici</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="199"/>
        <source>Compress</source>
        <translation>Compresser</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="209"/>
        <source>Properties</source>
        <translation>Propriétés</translation>
    </message>
</context>
<context>
    <name>Fm::FileOperation</name>
    <message>
        <location filename="../../fileoperation.cpp" line="227"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../../fileoperation.cpp" line="228"/>
        <source>Some files cannot be moved to trash can because the underlying file systems don&apos;t support this operation.
Do you want to delete them instead?</source>
        <translation>Certains fichiers ne peuvent pas être mis à la corbeille car les systèmes de fichiers sous-jacents ne prennent pas en charge cette opération.
Voulez-vous plutôt les supprimer ?</translation>
    </message>
    <message>
        <location filename="../../fileoperation.cpp" line="270"/>
        <location filename="../../fileoperation.cpp" line="287"/>
        <source>Confirm</source>
        <translation>Confirmer</translation>
    </message>
    <message>
        <location filename="../../fileoperation.cpp" line="271"/>
        <source>Do you want to delete the selected files?</source>
        <translation>Voulez-vous supprimer les fichiers sélectionnés ?</translation>
    </message>
    <message>
        <location filename="../../fileoperation.cpp" line="288"/>
        <source>Do you want to move the selected files to trash can?</source>
        <translation>Voulez-vous mettre les fichiers sélectionnés à la corbeille ?</translation>
    </message>
</context>
<context>
    <name>Fm::FileOperationDialog</name>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="41"/>
        <source>Move files</source>
        <translation>Déplacer les fichiers</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="42"/>
        <source>Moving the following files to destination folder:</source>
        <translation>Déplacement des fichiers suivants vers le dossier de destination en cours :</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="45"/>
        <source>Copy Files</source>
        <translation>Copier les fichiers</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="46"/>
        <source>Copying the following files to destination folder:</source>
        <translation>Copie des fichiers suivants vers le dossier de destination en cours :</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="49"/>
        <source>Trash Files</source>
        <translation>Mettre les fichiers de la corbeille</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="50"/>
        <source>Moving the following files to trash can:</source>
        <translation>Déplacement des fichiers suivants vers la corbeille en cours :</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="53"/>
        <source>Delete Files</source>
        <translation>Supprimer les fichiers</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="54"/>
        <source>Deleting the following files:</source>
        <translation>Suppression des fichiers suivants :</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="59"/>
        <source>Create Symlinks</source>
        <translation>Créer des liens symboliques</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="60"/>
        <source>Creating symlinks for the following files:</source>
        <translation>Création de liens symboliques avec les fichiers suivants en cours :</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="63"/>
        <source>Change Attributes</source>
        <translation>Modifier les attributs</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="64"/>
        <source>Changing attributes of the following files:</source>
        <translation>Modification des attributs des fichiers suivants en cours :</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="69"/>
        <source>Restore Trashed Files</source>
        <translation>Restaurer les fichiers de la corbeille</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="70"/>
        <source>Restoring the following files from trash can:</source>
        <translation>Restauration des fichiers suivants depuis la corbeille en cours :</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="134"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
</context>
<context>
    <name>Fm::FilePropsDialog</name>
    <message>
        <location filename="../../filepropsdialog.cpp" line="156"/>
        <source>View folder content</source>
        <translation>Voir le contenu du dossier</translation>
    </message>
    <message>
        <location filename="../../filepropsdialog.cpp" line="157"/>
        <source>View and modify folder content</source>
        <translation>Voir et modifier le contenu du dossier</translation>
    </message>
    <message>
        <location filename="../../filepropsdialog.cpp" line="161"/>
        <source>Read</source>
        <translation>Lecture</translation>
    </message>
    <message>
        <location filename="../../filepropsdialog.cpp" line="162"/>
        <source>Read and write</source>
        <translation>Lecture et écriture</translation>
    </message>
    <message>
        <location filename="../../filepropsdialog.cpp" line="164"/>
        <source>Forbidden</source>
        <translation>Interdit</translation>
    </message>
    <message>
        <location filename="../../filepropsdialog.cpp" line="281"/>
        <source>Files of different types</source>
        <translation>Fichiers de différents types</translation>
    </message>
    <message>
        <location filename="../../filepropsdialog.cpp" line="304"/>
        <source>Multiple Files</source>
        <translation>Fichiers multiples</translation>
    </message>
    <message>
        <location filename="../../filepropsdialog.cpp" line="380"/>
        <source>Select an icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../filepropsdialog.cpp" line="382"/>
        <source>Images (*.png *.xpm *.svg *.svgz )</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../filepropsdialog.cpp" line="478"/>
        <source>Apply changes</source>
        <translation>Appliquer les modifications</translation>
    </message>
    <message>
        <location filename="../../filepropsdialog.cpp" line="479"/>
        <source>Do you want to recursively apply these changes to all files and sub-folders?</source>
        <translation>Voulez-vous appliquer ces changements récursivement à tous les fichiers et sous-dossiers ?</translation>
    </message>
</context>
<context>
    <name>Fm::FileSearchDialog</name>
    <message>
        <location filename="../../filesearchdialog.cpp" line="128"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../../filesearchdialog.cpp" line="128"/>
        <source>You should add at least one directory to search.</source>
        <translation>Vous devriez indiquer au moins un dossier pour la recherche.</translation>
    </message>
    <message>
        <location filename="../../filesearchdialog.cpp" line="135"/>
        <source>Select a folder</source>
        <translation>Sélectionnez un dossier</translation>
    </message>
</context>
<context>
    <name>Fm::FolderMenu</name>
    <message>
        <location filename="../../foldermenu.cpp" line="41"/>
        <source>Create &amp;New</source>
        <translation>Créer un &amp;nouveau</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="48"/>
        <source>&amp;Paste</source>
        <translation>&amp;Coller</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="54"/>
        <source>Select &amp;All</source>
        <translation>Sélectionner &amp;tous</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="58"/>
        <source>Invert Selection</source>
        <translation>Inverser la sélection</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="64"/>
        <source>Sorting</source>
        <translation>Tri en cours</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="69"/>
        <source>Show Hidden</source>
        <translation>Afficher les éléments cachés</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="94"/>
        <source>Folder Pr&amp;operties</source>
        <translation>Pr&amp;opriétés du dossier</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation type="vanished">Dossier</translation>
    </message>
    <message>
        <source>File</source>
        <translation type="vanished">Fichier</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="137"/>
        <source>Output</source>
        <translation>Sortie</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="160"/>
        <source>By File Name</source>
        <translation>Par nom de fichier</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="161"/>
        <source>By Modification Time</source>
        <translation>Par date de modification</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="162"/>
        <source>By File Size</source>
        <translation>Par taille de fichier</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="163"/>
        <source>By File Type</source>
        <translation>Par type de fichier</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="164"/>
        <source>By File Owner</source>
        <translation>Par propriétaire de fichier</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="176"/>
        <source>Ascending</source>
        <translation>Ascendant</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="181"/>
        <source>Descending</source>
        <translation>Descendant</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="198"/>
        <source>Folder First</source>
        <translation>Dossier en premier</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="208"/>
        <source>Case Sensitive</source>
        <translation>Sensible à la casse</translation>
    </message>
</context>
<context>
    <name>Fm::FolderModel</name>
    <message>
        <location filename="../../foldermodel.cpp" line="242"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../../foldermodel.cpp" line="245"/>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <location filename="../../foldermodel.cpp" line="248"/>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <location filename="../../foldermodel.cpp" line="251"/>
        <source>Modified</source>
        <translation>Modifié</translation>
    </message>
    <message>
        <location filename="../../foldermodel.cpp" line="254"/>
        <source>Owner</source>
        <translation>Propriétaire</translation>
    </message>
</context>
<context>
    <name>Fm::FontButton</name>
    <message>
        <location filename="../../fontbutton.cpp" line="46"/>
        <source>Bold</source>
        <translation>Gras</translation>
    </message>
    <message>
        <location filename="../../fontbutton.cpp" line="50"/>
        <source>Italic</source>
        <translation>Italique</translation>
    </message>
</context>
<context>
    <name>Fm::MountOperationPasswordDialog</name>
    <message>
        <location filename="../../mountoperationpassworddialog.cpp" line="40"/>
        <source>&amp;Connect</source>
        <translation>&amp;Connecter</translation>
    </message>
</context>
<context>
    <name>Fm::PathBar</name>
    <message>
        <location filename="../../pathbar.cpp" line="126"/>
        <source>&amp;Edit Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../pathbar.cpp" line="129"/>
        <source>&amp;Copy Path</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Fm::PlacesModel</name>
    <message>
        <location filename="../../placesmodel.cpp" line="44"/>
        <source>Places</source>
        <translation>Emplacements</translation>
    </message>
    <message>
        <location filename="../../placesmodel.cpp" line="52"/>
        <source>Desktop</source>
        <translation>Bureau</translation>
    </message>
    <message>
        <location filename="../../placesmodel.cpp" line="231"/>
        <source>Trash</source>
        <translation>Corbeille</translation>
    </message>
    <message>
        <location filename="../../placesmodel.cpp" line="60"/>
        <source>Computer</source>
        <translation>Ordinateur</translation>
    </message>
    <message>
        <location filename="../../placesmodel.cpp" line="72"/>
        <source>Applications</source>
        <translation>Applications</translation>
    </message>
    <message>
        <location filename="../../placesmodel.cpp" line="81"/>
        <source>Network</source>
        <translation>Réseau</translation>
    </message>
    <message>
        <location filename="../../placesmodel.cpp" line="88"/>
        <source>Devices</source>
        <translation>Appareils</translation>
    </message>
    <message>
        <location filename="../../placesmodel.cpp" line="142"/>
        <source>Bookmarks</source>
        <translation>Signets</translation>
    </message>
</context>
<context>
    <name>Fm::PlacesView</name>
    <message>
        <location filename="../../placesview.cpp" line="370"/>
        <source>Empty Trash</source>
        <translation>Corbeille vide</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="vanished">Renommer</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="vanished">Supprimer</translation>
    </message>
    <message>
        <location filename="../../placesview.cpp" line="356"/>
        <source>Open in New Tab</source>
        <translation>Ouvrir dans un nouvel onglet</translation>
    </message>
    <message>
        <location filename="../../placesview.cpp" line="359"/>
        <source>Open in New Window</source>
        <translation>Ouvrir dans une nouvelle fenêtre</translation>
    </message>
    <message>
        <location filename="../../placesview.cpp" line="379"/>
        <source>Move Bookmark Up</source>
        <translation>Monter le signet</translation>
    </message>
    <message>
        <location filename="../../placesview.cpp" line="384"/>
        <source>Move Bookmark Down</source>
        <translation>Descendre le signet</translation>
    </message>
    <message>
        <location filename="../../placesview.cpp" line="388"/>
        <source>Rename Bookmark</source>
        <translation>Renommer le signet</translation>
    </message>
    <message>
        <location filename="../../placesview.cpp" line="391"/>
        <source>Remove Bookmark</source>
        <translation>Effacer le signet</translation>
    </message>
    <message>
        <location filename="../../placesview.cpp" line="400"/>
        <location filename="../../placesview.cpp" line="417"/>
        <source>Unmount</source>
        <translation>Démonter</translation>
    </message>
    <message>
        <location filename="../../placesview.cpp" line="404"/>
        <source>Mount</source>
        <translation>Monter</translation>
    </message>
    <message>
        <location filename="../../placesview.cpp" line="410"/>
        <source>Eject</source>
        <translation>Éjecter</translation>
    </message>
</context>
<context>
    <name>Fm::RenameDialog</name>
    <message>
        <location filename="../../renamedialog.cpp" line="50"/>
        <location filename="../../renamedialog.cpp" line="69"/>
        <source>Type: %1
Size: %2
Modified: %3</source>
        <translation>Type : %1
Taille : %2
Modification : %3</translation>
    </message>
    <message>
        <location filename="../../renamedialog.cpp" line="56"/>
        <location filename="../../renamedialog.cpp" line="75"/>
        <source>Type: %1
Modified: %2</source>
        <translation>Type : %1
Modification : %2</translation>
    </message>
    <message>
        <location filename="../../renamedialog.cpp" line="89"/>
        <source>&amp;Overwrite</source>
        <translation>&amp;Remplacer</translation>
    </message>
    <message>
        <location filename="../../renamedialog.cpp" line="91"/>
        <source>&amp;Rename</source>
        <translation>&amp;Renommer</translation>
    </message>
</context>
<context>
    <name>Fm::SidePane</name>
    <message>
        <location filename="../../sidepane.cpp" line="46"/>
        <source>Places</source>
        <translation>Emplacements</translation>
    </message>
    <message>
        <location filename="../../sidepane.cpp" line="47"/>
        <source>Directory Tree</source>
        <translation>Arborescence des répertoires</translation>
    </message>
    <message>
        <source>Shows list of common places, devices, and bookmarks in sidebar</source>
        <translation type="vanished">Afficher la liste des principaux emplacements, périphériques et raccourcis dans le panneau latéral</translation>
    </message>
    <message>
        <source>Shows tree of directories in sidebar</source>
        <translation type="vanished">Afficher l&apos;arborescence des répertoires dans le panneau latéral</translation>
    </message>
</context>
<context>
    <name>MountOperationPasswordDialog</name>
    <message>
        <location filename="../../mount-operation-password.ui" line="20"/>
        <source>Mount</source>
        <translation>Monter</translation>
    </message>
    <message>
        <location filename="../../mount-operation-password.ui" line="48"/>
        <source>Connect &amp;anonymously</source>
        <translation>Connecter &amp;anonymement</translation>
    </message>
    <message>
        <location filename="../../mount-operation-password.ui" line="58"/>
        <source>Connect as u&amp;ser:</source>
        <translation>Connecter comme utilis&amp;sateur :</translation>
    </message>
    <message>
        <location filename="../../mount-operation-password.ui" line="79"/>
        <source>&amp;Username:</source>
        <translation>Nom d&apos;&amp;utilisateur :</translation>
    </message>
    <message>
        <location filename="../../mount-operation-password.ui" line="102"/>
        <source>&amp;Password:</source>
        <translation>Mot de &amp;passe :</translation>
    </message>
    <message>
        <location filename="../../mount-operation-password.ui" line="112"/>
        <source>&amp;Domain:</source>
        <translation>&amp;Domaine :</translation>
    </message>
    <message>
        <location filename="../../mount-operation-password.ui" line="127"/>
        <source>Forget password &amp;immediately</source>
        <translation>Oublier le mot de passe &amp;immédiatement</translation>
    </message>
    <message>
        <location filename="../../mount-operation-password.ui" line="137"/>
        <source>Remember password until you &amp;logout</source>
        <translation>Se souvenir du mot de passe jusqu&apos;à &amp;la déconnexion</translation>
    </message>
    <message>
        <location filename="../../mount-operation-password.ui" line="147"/>
        <source>Remember &amp;forever</source>
        <translation>&amp;Toujours s&apos;en souvenir</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../utilities.cpp" line="143"/>
        <location filename="../../utilities.cpp" line="232"/>
        <location filename="../../mountoperation.cpp" line="186"/>
        <location filename="../../filepropsdialog.cpp" line="503"/>
        <location filename="../../filelauncher.cpp" line="139"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../../utilities.cpp" line="149"/>
        <source>Rename File</source>
        <translation>Renommer le fichier</translation>
    </message>
    <message>
        <location filename="../../utilities.cpp" line="150"/>
        <source>Please enter a new name:</source>
        <translation>Veuillez entrer un nouveau nom :</translation>
    </message>
    <message>
        <location filename="../../utilities.cpp" line="174"/>
        <source>Create Folder</source>
        <translation>Créer un dossier</translation>
    </message>
    <message>
        <location filename="../../utilities.cpp" line="179"/>
        <source>Please enter a new file name:</source>
        <translation>Veuillez entrer un nouveau nom de fichier :</translation>
    </message>
    <message>
        <location filename="../../utilities.cpp" line="180"/>
        <source>New text file</source>
        <translation>Nouveau fichier texte</translation>
    </message>
    <message>
        <location filename="../../utilities.cpp" line="184"/>
        <source>Please enter a new folder name:</source>
        <translation>Veuillez entrer un nouveau nom de répertoire :</translation>
    </message>
    <message>
        <location filename="../../utilities.cpp" line="185"/>
        <source>New folder</source>
        <translation>Nouveau répertoire</translation>
    </message>
    <message>
        <location filename="../../utilities.cpp" line="190"/>
        <source>Enter a name for the new %1:</source>
        <translation>Entrez un nom pour le nouveau %1 :</translation>
    </message>
    <message>
        <location filename="../../utilities.cpp" line="175"/>
        <source>Create File</source>
        <translation>Créer un fichier</translation>
    </message>
    <message>
        <location filename="../../filepropsdialog.cpp" line="520"/>
        <source>Custom Icon Error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <location filename="../../rename-dialog.ui" line="14"/>
        <source>Confirm to replace files</source>
        <translation>Confirmer le remplacement des fichiers</translation>
    </message>
    <message>
        <location filename="../../rename-dialog.ui" line="35"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;There is already a file with the same name in this location.&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Do you want to replace the existing file?&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Il existe déjà un fichier avec le même nom à cet emplacement.&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Voulez-vous replacer le fichier existant ?&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../rename-dialog.ui" line="56"/>
        <source>dest</source>
        <translation>dst</translation>
    </message>
    <message>
        <location filename="../../rename-dialog.ui" line="63"/>
        <source>with the following file?</source>
        <translation>avec le fichier suivant ?</translation>
    </message>
    <message>
        <location filename="../../rename-dialog.ui" line="76"/>
        <source>src file info</source>
        <translation>infos fichier src</translation>
    </message>
    <message>
        <location filename="../../rename-dialog.ui" line="89"/>
        <source>dest file info</source>
        <translation>infos fichier dst</translation>
    </message>
    <message>
        <location filename="../../rename-dialog.ui" line="102"/>
        <source>src</source>
        <translation>src</translation>
    </message>
    <message>
        <location filename="../../rename-dialog.ui" line="122"/>
        <source>&amp;File name:</source>
        <translation>Nom de &amp;fichier :</translation>
    </message>
    <message>
        <location filename="../../rename-dialog.ui" line="137"/>
        <source>Apply this option to all existing files</source>
        <translation>Appliquer cette option à tous les fichiers existants</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <location filename="../../filesearch.ui" line="14"/>
        <source>Search Files</source>
        <translation>Recherche de fichiers</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="29"/>
        <source>Name/Location</source>
        <translation>Nom/Emplacement</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="35"/>
        <source>File Name Patterns:</source>
        <translation>Motifs dans le nom des fichiers :</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="41"/>
        <source>*</source>
        <translation>*</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="48"/>
        <source>Case insensitive</source>
        <translation>Insensible à la casse</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="55"/>
        <source>Use regular expression</source>
        <translation>Utiliser les expressions rationnelles</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="65"/>
        <source>Places to Search:</source>
        <translation>Emplacements de la recherche :</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="78"/>
        <source>&amp;Add</source>
        <translation>&amp;Ajouter</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="90"/>
        <source>&amp;Remove</source>
        <translation>&amp;Supprimer</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="119"/>
        <source>Search in sub directories</source>
        <translation>Recherche dans les sous-répertoires</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="126"/>
        <source>Search for hidden files</source>
        <translation>Rechercher les fichiers cachés</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="137"/>
        <source>File Type</source>
        <translation>Type de fichier</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="143"/>
        <source>Only search for files of following types:</source>
        <translation>Rechercher uniquement les types de fichiers suivants :</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="149"/>
        <source>Text files</source>
        <translation>Fichiers texte</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="156"/>
        <source>Image files</source>
        <translation>Fichiers image</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="163"/>
        <source>Audio files</source>
        <translation>Fichiers audio</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="170"/>
        <source>Video files</source>
        <translation>Fichiers vidéo</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="177"/>
        <source>Documents</source>
        <translation>Documents</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="184"/>
        <source>Folders</source>
        <translation>Dossiers</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="208"/>
        <source>Content</source>
        <translation>Contenu</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="214"/>
        <source>File contains:</source>
        <translation>Le fichier contient :</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="223"/>
        <source>Case insensiti&amp;ve</source>
        <translation>&amp;Insensible à la casse</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="230"/>
        <source>&amp;Use regular expression</source>
        <translation>&amp;Utiliser les expressions rationelles</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="254"/>
        <source>Properties</source>
        <translation>Propriétés</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="260"/>
        <source>File Size:</source>
        <translation>Taille du fichier :</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="289"/>
        <source>Larger than:</source>
        <translation>Plus grands que :</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="303"/>
        <location filename="../../filesearch.ui" line="333"/>
        <source>Bytes</source>
        <translation>Octets</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="308"/>
        <location filename="../../filesearch.ui" line="338"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="313"/>
        <location filename="../../filesearch.ui" line="343"/>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="318"/>
        <location filename="../../filesearch.ui" line="348"/>
        <source>GiB</source>
        <translation>GiB</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="268"/>
        <source>Smaller than:</source>
        <translation>Plus petits que :</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="364"/>
        <source>Last Modified Time:</source>
        <translation>Date de dernièremodification :</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="372"/>
        <source>Earlier than:</source>
        <translation>Plus récent que :</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="379"/>
        <source>Later than:</source>
        <translation>Plus ancien que :</translation>
    </message>
</context>
</TS>
